package com.liquidnet.service.adam.dto;

import com.liquidnet.commons.lang.constant.LnsRegex;
import com.liquidnet.service.adam.dto.vo.AdamTagParentVo;
import com.liquidnet.service.adam.dto.vo.AdamTagVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import java.util.List;

@ApiModel(value = "AdamUserInfoParam", description = "个人资料编辑参数")
@Data
public class AdamUserInfoParam implements java.io.Serializable {
    private static final long serialVersionUID = -1084524066864012398L;
    @ApiModelProperty(position = 11, required = true, value = "头像[255]", example = "http://pic.zhengzai.tv/default/avatar.png")
//    @Size(max = 255, message = "已超出头像链接长度限制")
    private String avatar;
    @ApiModelProperty(position = 12, required = true, value = "背景[255]", example = "https://img.zhengzai.tv/files/2021/01/13/5ffeab3584b7d.png")
//    @Size(max = 255, message = "已超出背景链接长度限制")
    private String background;
    @ApiModelProperty(position = 13, required = true, value = "昵称[14]", example = "Swagger")
    @Size(min = 2, max = 14, message = "昵称限制2-14位且不能包含特殊字符")
    private String nickname;
    @ApiModelProperty(position = 14, required = true, value = "性别[32]", example = "{\"val\":\"MS00\",\"desc\":\"其他性别\"}")
//    @NotNull(message = "性别不能为空")
    private AdamTagVo sex;
    @ApiModelProperty(position = 15, required = true, value = "生日[YYYY-MM-DD]", example = "2021-05-17")
    @Pattern(regexp = LnsRegex.Valid.DATETIME_YMD, message = "生日格式有误")
//    @NotBlank(message = "生日不能为空")
    private String birthday;
    @ApiModelProperty(position = 16, required = false, value = "常住地/区域[100] ～ 已废除，参见[province、city、county]", example = "北京 北京市 朝阳区")
    @NotBlank(message = "常住地不能为空")
    private String area;
    @ApiModelProperty(position = 17, required = true, value = "签名[30]", example = "...................")
//    @Size(max = 30, message = "已超出签名长度限制")
    private String signature;
    @ApiModelProperty(position = 18, required = true, value = "标签[500]", example = "[{\"val\":\"MMS01\",\"desc\":\"民歌\",\"tagVos\":[{\"val\":\"MMS0101\",\"desc\":\"A\"},{\"val\":\"MMS0102\",\"desc\":\"B\"}]},{\"val\":\"MMS02\",\"desc\":\"house\",\"tagVos\":[{\"val\":\"MMS0201\",\"desc\":\"C\"}]}]")
    private List<AdamTagParentVo> tagMe;
    @ApiModelProperty(position = 19, required = false, value = "常住地/省[50] ～ 替换原字段[area]", example = "北京市")
    private String province;
    @ApiModelProperty(position = 20, required = false, value = "常住地/市[50] ～ 替换原字段[area]", example = "北京市")
    private String city;
    @ApiModelProperty(position = 21, required = false, value = "常住地/区县[50] ～ 替换原字段[area]", example = "朝阳区")
    private String county;
}
